*{font-family:Verdana}table{width:100%}table tr td{padding:5px}.title{font-size:48px;font-weight:bold}ul.breadcrumbs li{display:inline;list-style:none;padding:0 2px}ul.breadcrumbs li+li:before{color:#000;content:"/ "}td.number{text-align:right}/*# sourceMappingURL=power_query.css.map */
