# Generated by Django 3.2.19 on 2023-06-05 11:02

import django.db.models.deletion
from django.db import migrations, models

import power_query.json


class Migration(migrations.Migration):
    dependencies = [
        ("power_query", "0013_migration"),
    ]

    operations = [
        migrations.AddField(
            model_name="parametrizer",
            name="source",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="power_query.query",
            ),
        ),
        migrations.AddField(
            model_name="query",
            name="celery_task",
            field=models.CharField(blank=True, max_length=36, null=True),
        ),
        migrations.AddField(
            model_name="report",
            name="celery_task",
            field=models.CharField(blank=True, max_length=36, null=True),
        ),
        migrations.AlterField(
            model_name="reportdocument",
            name="arguments",
            field=models.JSONField(
                default=dict, encoder=power_query.json.PQJSONEncoder
            ),
        ),
    ]
