# Generated by Django 3.2.18 on 2023-05-31 14:32

from django.db import migrations, models

import power_query.json


class Migration(migrations.Migration):
    dependencies = [
        ("power_query", "0008_migration"),
    ]

    operations = [
        migrations.AlterField(
            model_name="query",
            name="info",
            field=models.JSONField(
                blank=True, default=dict, encoder=power_query.json.PQJSONEncoder
            ),
        ),
    ]
