# Generated by Django 3.2.18 on 2023-06-01 06:00

from django.db import migrations, models

import power_query.validators


class Migration(migrations.Migration):
    dependencies = [
        ("power_query", "0010_migration"),
    ]

    operations = [
        migrations.AlterField(
            model_name="report",
            name="frequence",
            field=models.CharField(
                blank=True,
                default="mon,tue,wed,thu,fri,sat,sun",
                help_text="Refresh every (e.g. 3 - 1/3 - mon - 1/3,Mon)",
                max_length=30,
                null=True,
                validators=[power_query.validators.FrequencyValidator],
            ),
        ),
    ]
