# Generated by Django 3.2 on 2022-02-11 19:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("power_query", "0002_migration"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dataset",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="dataset",
            name="info",
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name="formatter",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="query",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="query",
            name="info",
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name="query",
            name="query_args",
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name="report",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="report",
            name="query_args",
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
