# Generated by Django 3.2.18 on 2023-05-19 08:20

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("power_query", "0012_migration"),
    ]

    operations = [
        migrations.AlterField(
            model_name="formatter",
            name="content_type",
            field=models.CharField(
                choices=[
                    ("csv", "text/csv"),
                    ("html", "text/html"),
                    ("json", "application/json"),
                    ("txt", "text/plain"),
                    ("xls", "application/vnd.ms-excel"),
                    ("xml", "application/xml"),
                    ("yaml", "text/yaml"),
                ],
                max_length=5,
            ),
        ),
        migrations.AlterField(
            model_name="reportdocument",
            name="content_type",
            field=models.CharField(choices=[], max_length=5),
        ),
    ]
