{% extends "power_query/base.html" %}{% load admin_urls %}

{% block body %}
    {{ report }}
    <table>
        {% for report in reports %}
            <tr>
                <td><a href="{{ report.get_absolute_url }}">{{ report.name }}</a></td>
                <td></td>
            </tr>
        {% endfor %}
    </table>
{% endblock %}
